@@ -523,17 +523,15 @@ where
 
     fn can_inline_fn_like(&self, param_ids: &[Ident], body: &BlockStmt) -> bool {
         // Don't create top-level variables.
-        if !param_ids.is_empty() {
-            if self.ctx.in_top_level() && !self.options.module {
-                for pid in param_ids {
-                    if let Some(usage) = self
-                        .data
-                        .as_ref()
-                        .and_then(|data| data.vars.get(&pid.to_id()))
-                    {
-                        if usage.ref_count > 1 || usage.assign_count > 0 || usage.inline_prevented {
-                            return false;
-                        }
+        if !param_ids.is_empty() && self.ctx.in_top_level() {
+            for pid in param_ids {
+                if let Some(usage) = self
+                    .data
+                    .as_ref()
+                    .and_then(|data| data.vars.get(&pid.to_id()))
+                {
+                    if usage.ref_count > 1 || usage.assign_count > 0 || usage.inline_prevented {
+                        return false;
                     }
                 }
             }
